@@ -1,5 +1,6 @@
 use crate::search::*;
 use crate::util::*;
+
 /// Returns documents matching one or more wrapped queries, called query clauses or clauses.
 ///
 /// If a returned document matches multiple query clauses, the `dis_max` query assigns the document
@@ -31,7 +32,7 @@ pub struct DisMaxQuery {
 
 #[derive(Debug, Clone, Default, PartialEq, Serialize)]
 struct Inner {
-    queries: Vec<Query>,
+    queries: Queries,
 
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
     tie_breaker: Option<TieBreaker>,
@@ -55,33 +56,11 @@ impl DisMaxQuery {
     /// **must match one or more** of these queries. If a document matches multiple queries,
     /// Elasticsearch uses the highest
     /// [relevance score](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-filter-context.html)
-    pub fn query(mut self, query: impl Into<Option<Query>>) -> Self {
-        let query = query.into();
-
-        if let Some(query) = query {
-            if !query.should_skip() {
-                self.inner.queries.push(query);
-            }
-        }
-
-        self
-    }
-
-    /// Contains one or more query clauses. Returned documents
-    /// **must match one or more** of these queries. If a document matches multiple queries,
-    /// Elasticsearch uses the highest
-    /// [relevance score](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-filter-context.html)
-    pub fn queries<I>(mut self, queries: I) -> Self
+    pub fn query<Q>(mut self, queries: Q) -> Self
     where
-        I: IntoIterator,
-        I::Item: Into<Query>,
+        Q: Into<Queries>,
     {
-        for query in queries.into_iter().map(Into::into) {
-            if !query.should_skip() {
-                self.inner.queries.push(query);
-            }
-        }
-
+        self.inner.queries.extend(queries);
         self
     }
 
@@ -103,8 +82,13 @@ impl DisMaxQuery {
     ///
     /// If the `tie_breaker` value is greater than `0.0`, all matching clauses
     /// count, but the clause with the highest score counts most.
-    pub fn tie_breaker(mut self, tie_breaker: impl Into<TieBreaker>) -> Self {
-        self.inner.tie_breaker = Some(tie_breaker.into());
+    pub fn tie_breaker<T>(mut self, tie_breaker: T) -> Self
+    where
+        T: std::convert::TryInto<TieBreaker>,
+    {
+        if let Ok(tie_breaker) = tie_breaker.try_into() {
+            self.inner.tie_breaker = Some(tie_breaker);
+        }
         self
     }
 
@@ -121,8 +105,9 @@ impl ShouldSkip for DisMaxQuery {
 mod tests {
     use super::*;
 
-    test_serialization! {
-        with_required_fields(
+    #[test]
+    fn serialization() {
+        assert_serialize(
             Query::dis_max()
                 .query(Query::r#match("t1", "text"))
                 .query(Query::r#match("t2", "text")),
@@ -145,12 +130,11 @@ mod tests {
                         }
                     ]
                 }
-            })
+            }),
         );
 
-        with_multiple_queries(
-            Query::dis_max()
-                .queries([Query::r#match("t1", "text"), Query::r#match("t2", "text")]),
+        assert_serialize(
+            Query::dis_max().query([Query::r#match("t1", "text"), Query::r#match("t2", "text")]),
             json!({
                 "dis_max": {
                     "queries": [
@@ -170,10 +154,10 @@ mod tests {
                         }
                     ]
                 }
-            })
+            }),
         );
 
-        with_all_fields(
+        assert_serialize(
             Query::dis_max()
                 .query(Query::r#match("t1", "text"))
                 .query(Query::r#match("t2", "text"))
@@ -202,7 +186,7 @@ mod tests {
                     "boost": 3,
                     "_name": "test"
                 }
-            })
+            }),
         );
     }
 }
