@@ -5,9 +5,11 @@ mod boost;
 mod fuzziness;
 mod has_child_query;
 mod inner_hits;
+mod minimum_should_match;
 mod negative_boost;
 mod operator;
 mod rewrite;
+mod script_object;
 mod tie_breaker;
 mod zero_terms_query;
 
@@ -22,7 +24,6 @@ mod range_query;
 mod regexp_query;
 mod shape_query;
 mod simple_query_string_query;
-mod terms_query;
 mod terms_set_query;
 
 // Public re-exports
@@ -32,6 +33,7 @@ pub use self::fuzziness::*;
 pub use self::geo_query::*;
 pub use self::has_child_query::*;
 pub use self::inner_hits::*;
+pub use self::minimum_should_match::*;
 pub use self::multi_match_query::*;
 pub use self::negative_boost::*;
 pub use self::nested_query::*;
@@ -41,14 +43,9 @@ pub use self::pinned_query::*;
 pub use self::range_query::*;
 pub use self::regexp_query::*;
 pub use self::rewrite::*;
+pub use self::script_object::*;
 pub use self::shape_query::*;
 pub use self::simple_query_string_query::*;
-pub use self::terms_query::*;
 pub use self::terms_set_query::*;
 pub use self::tie_breaker::*;
 pub use self::zero_terms_query::*;
-
-/// The `minimum_should_match` type alias
-///
-/// <https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-minimum-should-match.html>
-pub type MinimumShouldMatch = String;
