@@ -11,6 +11,7 @@ mod prefix_query;
 mod range_query;
 mod regexp_query;
 mod term_query;
+mod terms_lookup_query;
 mod terms_query;
 mod terms_set_query;
 mod wildcard_query;
@@ -22,6 +23,7 @@ pub use self::prefix_query::*;
 pub use self::range_query::*;
 pub use self::regexp_query::*;
 pub use self::term_query::*;
+pub use self::terms_lookup_query::*;
 pub use self::terms_query::*;
 pub use self::terms_set_query::*;
 pub use self::wildcard_query::*;
