@@ -61,7 +61,7 @@ pub struct Hits<H, IH> {
 }
 
 /// Represents a single matched document
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
 pub struct Hit<H, IH> {
     /// Document index
     #[serde(skip_serializing_if = "ShouldSkip::should_skip", rename = "_index")]
@@ -101,13 +101,6 @@ pub struct Hit<H, IH> {
     pub fields: std::collections::BTreeMap<String, Value>,
 }
 
-/// Hit can be considered equal to another hit when index and id are equal
-impl<H, IH> PartialEq for Hit<H, IH> {
-    fn eq(&self, other: &Self) -> bool {
-        self.index == other.index && self.id == other.id
-    }
-}
-
 /// Represents inner hits
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
 pub struct InnerHitsResponse<IH> {
